==> haskell-th-abstraction-0.4.3.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-abstraction
version:              0.4.3.0
visibility:           public
id:                   th-abstraction-0.4.3.0-DBpnRpG8EZgFebz88L1kOA
key:                  th-abstraction-0.4.3.0-DBpnRpG8EZgFebz88L1kOA
license:              ISC
copyright:            2017 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/th-abstraction
synopsis:             Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.

category:             Development
abi:                  a90d9799ca083207d4d5012d14fccda4
exposed:              True
exposed-modules:
    Language.Haskell.TH.Datatype Language.Haskell.TH.Datatype.TyVarBndr

hidden-modules:       Language.Haskell.TH.Datatype.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-abstraction-0.4.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-abstraction-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-abstraction-0.4.3.0
hs-libraries:         HSth-abstraction-0.4.3.0-DBpnRpG8EZgFebz88L1kOA
depends:
    base-4.15.0.0 containers-0.6.4.1 ghc-prim-0.7.0
    template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock

haddock-html:         /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-abstraction-0.4.5.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-abstraction
version:              0.4.5.0
visibility:           public
id:                   th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp
key:                  th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp
license:              ISC
copyright:            2017 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/th-abstraction
synopsis:             Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.

category:             Development
abi:                  6c12857d1b8a4e390bb3656d989ce025
exposed:              True
exposed-modules:
    Language.Haskell.TH.Datatype Language.Haskell.TH.Datatype.TyVarBndr

hidden-modules:       Language.Haskell.TH.Datatype.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-abstraction-0.4.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-abstraction-0.4.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-abstraction
hs-libraries:         HSth-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp
depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-prim-0.7.0
    template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock

haddock-html:         /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
